<?php
/**
* 2007-2020 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2020 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

require_once(_PS_ROOT_DIR_ . '/modules/adamspay/classes/AdamspayLog.php');
require_once(_PS_ROOT_DIR_ . '/modules/adamspay/classes/AdamspayHelper.php');
require_once(_PS_ROOT_DIR_ . '/modules/adamspay/classes/AdamspayDeuda.php');
require_once(_PS_ROOT_DIR_ . '/modules/adamspay/classes/AdamspayApi.php');

use Adamspay\AdamspayLog;
use Adamspay\AdamspayHelper;
use Adamspay\AdamspayApi;

class Adamspay extends PaymentModule
{
    protected $config_form = false;

    protected $url_agradecimiento;
    protected $url_respuesta;
    protected $url_webhook;
    protected $url_redirect_adamspay;
    protected $callback_urls;
    protected $order_canceled = 6;
    protected $adamspayHelper;
    protected $adamspayLog;

    public function __construct()
    {
        $this->name = 'adamspay';
        $this->tab = 'payments_gateways';
        $this->version = '1.0.0';
        $this->author = 'adamspay.com';
        $this->need_instance = 1;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Adamspay - Cobros online para tu eCommerce');
        $this->description = $this->l('Adamspay es un sistema de cobro online para aplicaciones móviles y sitios web que permite recibir pagos a través de todos los canales habilitados por el comercio.
Está compuesto por un servicio en la nube y el API con el cual se enlaza al software del comercio.');

        $this->confirmUninstall = $this->l('Esta seguro que desea desinstalar?');

        $this->limited_countries = array('PY');

        $this->limited_currencies = array('PGY', 'USD', 'EUR');

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);

        $this->url_agradecimiento = Context::getContext()->link->getModuleLink(
            'adamspay',
            'pedido',
            array()
        );

        $this->url_respuesta = Context::getContext()->link->getModuleLink(
            'adamspay',
            'validation',
            array()
        );

        $this->url_webhook = Context::getContext()->link->getModuleLink(
            'adamspay',
            'webhook',
            array()
        );

        $this->url_redirect_adamspay = Context::getContext()->link->getModuleLink(
            'adamspay',
            'generateLink',
            array()
        );

        $this->callback_urls = [
            'ADAMSPAY_URL_RESPUESTA',
            'ADAMSPAY_URL_WEBHOOK',
            'ADAMSPAY_URL_REDIRECT',
        ];

        $this->adamspayHelper = new AdamspayHelper;
        $this->adamspayLog = new AdamspayLog;
        $this->secure_key = Tools::encrypt($this->name);
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        if (extension_loaded('curl') == false)
        {
            $this->_errors[] = $this->l('La extension cURL es requerida para instalar este módulo');
            return false;
        }

        $iso_code = Country::getIsoById(Configuration::get('PS_COUNTRY_DEFAULT'));

        if (in_array($iso_code, $this->limited_countries) == false)
        {
            $this->_errors[] = $this->l('Este módulo no se encuentra disponible para tu pais');
            return false;
        }

        $url_desarrollo = "https://dev.adamspay.com/api/v1";
        $url_pruebas = "https://staging.adamspay.com/api/v1";
        $url_producion = "https://checkout.adamspay.com/api/v1";

        // Agregamos en la DB la config de ADAMSPAY
        // Solo al instalar usa la funcion. Puede cambiar dps.
        Configuration::updateValue('ADAMSPAY_PREFIJO_WEB', $this->adamspayHelper->acortarNombreTienda());
        // La descripción, caratula o Label para la deuda en Adamspay
        Configuration::updateValue('ADAMSPAY_LABEL_DEUDAS', Configuration::get('PS_SHOP_NAME'));
        Configuration::updateValue('ADAMSPAY_API_KEY_APP', '');
        Configuration::updateValue('ADAMSPAY_API_SECRET_APP', '');
        Configuration::updateValue('ADAMSPAY_MODO_PRODUCCION', false);
        Configuration::updateValue('ADAMSPAY_URL_PRUEBAS', $url_pruebas);
        Configuration::updateValue('ADAMSPAY_URL_PRODUCCION', $url_producion);
        Configuration::updateValue('ADAMSPAY_URL_DESARROLLO', $url_desarrollo);
        Configuration::updateValue('ADAMSPAY_URL_COMPRA', '');
        Configuration::updateValue('ADAMSPAY_URL_RESPUESTA', '');
        Configuration::updateValue('ADAMSPAY_URL_WEBHOOK', '');
        Configuration::updateValue('ADAMSPAY_URL_REDIRECT', '');
        Configuration::updateValue('ADAMSPAY_LABEL_METODO_PAGO', 'Pago online vía AdamsPay');
        Configuration::updateValue('ADAMSPAY_MENSAJE_PAGO_PENDIENTE', 'El pedido ha sido creado, pero el pago se encuentra PENDIENTE');

        include(dirname(__FILE__).'/sql/install.php');

        $this->setStatus();

        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('backOfficeHeader') &&
            $this->registerHook('payment') &&
            $this->registerHook('paymentReturn') &&
            $this->registerHook('paymentOptions') &&
            $this->registerHook('actionPaymentConfirmation') &&
            $this->registerHook('displayPayment') &&
            $this->registerHook('displayPaymentReturn') &&
            $this->registerHook('displayOrderDetail') &&
            $this->registerHook('displayAdminOrder') &&
            $this->registerHook('displayAdminOrderLeft') &&
            $this->registerHook('displayOrderConfirmation') &&
            $this->registerHook('actionOrderStatusPostUpdate') &&
            $this->registerHook('displayPaymentTop');
    }

    public function uninstall()
    {
        Configuration::deleteByName('ADAMSPAY_PREFIJO_WEB');
        Configuration::deleteByName('ADAMSPAY_LABEL_DEUDAS');
        Configuration::deleteByName('ADAMSPAY_API_KEY_APP');
        Configuration::deleteByName('ADAMSPAY_API_SECRET_APP');
        Configuration::deleteByName('ADAMSPAY_MODO_PRODUCCION');
        Configuration::deleteByName('ADAMSPAY_URL_PRUEBAS');
        Configuration::deleteByName('ADAMSPAY_URL_PRODUCCION');
        Configuration::deleteByName('ADAMSPAY_URL_DESARROLLO');
        Configuration::deleteByName('ADAMSPAY_URL_COMPRA');
        Configuration::deleteByName('ADAMSPAY_URL_RESPUESTA');
        Configuration::deleteByName('ADAMSPAY_URL_WEBHOOK');
        Configuration::deleteByName('ADAMSPAY_URL_REDIRECT');
        Configuration::deleteByName('ADAMSPAY_MENSAJE_PAGO_PENDIENTE');
        Configuration::deleteByName('ADAMSPAY_LABEL_METODO_PAGO');

        include(dirname(__FILE__).'/sql/uninstall.php');

        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        $url_agradecimiento = Configuration::get('ADAMSPAY_URL_COMPRA');
        $url_respuesta = Configuration::get('ADAMSPAY_URL_RESPUESTA');
        $url_webhook = Configuration::get('ADAMSPAY_URL_WEBHOOK');
        $url_redirect_adamspay = Configuration::get('ADAMSPAY_URL_REDIRECT');

        if (empty($url_agradecimiento)){
            Configuration::updateValue('ADAMSPAY_URL_COMPRA', $this->url_agradecimiento);
        }

        if(empty($url_respuesta)){
            Configuration::updateValue('ADAMSPAY_URL_RESPUESTA', $this->url_respuesta);
        }

        if(empty($url_webhook)) {
            Configuration::updateValue('ADAMSPAY_URL_WEBHOOK', $this->url_webhook);
        }

        if (empty($url_redirect_adamspay)) {
            Configuration::updateValue('ADAMSPAY_URL_REDIRECT', $this->url_redirect_adamspay);
        }

        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitAdamspayModule')) == true) {
            $process = $this->postProcess();
            if(is_array($process)){
                $this->context->smarty->assign('errors', $process);
            }
        }

        $this->context->smarty->assign('module_dir', $this->_path);
        $this->context->smarty->assign('produccion', Configuration::get('ADAMSPAY_MODO_PRODUCCION'));
        $this->context->smarty->assign('api_es_null', (Configuration::get('ADAMSPAY_API_KEY_APP') == '') ? true : false);
        $this->context->smarty->assign('secret_es_null', (Configuration::get('ADAMSPAY_API_SECRET_APP') == '') ? true : false);

        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAdamspayModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        $log_url = Tools::getShopDomainSsl(true) . $this->_path . 'error-log.php?secure_key=' . $this->secure_key . '&id_shop=' . $this->context->shop->id;

        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Configuración AdamsPay'),
                    'icon' => 'icon-cogs',
                ),
                'description' => $this->l('Puede verificar el fichero de log aquí:') . ' <a target="_blank" href="' . $log_url . '">' . $log_url . '</a>'
                . '</br></br>',
                'input' => array(
                    array(
                        'type' => 'select',
                        'label' => $this->l('Ambiente'),
                        'name' => 'ADAMSPAY_MODO_PRODUCCION',
                        'desc' => $this->l('Ambiente en donde se ejecutaran los pagos en AdamsPay'),
                        'options' => array(
                            'query' => array(
                                array(
                                    'id' => 1,
                                    'name' => $this->l('Modo Producción'),
                                ),
                                array(
                                    'id' => 0,
                                    'name' => $this->l('Modo Pruebas')
                                ),
                                array(
                                    'id' => 2,
                                    'name' => $this->l('Modo Dev')
                                )
                            ),
                            'id' => 'id',
                            'name' => 'name'
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'desc' => $this->l('El prefijo para el código de deuda. Máx 10 caracteres. Debe terminar con un \'_\''),
                        'name' => 'ADAMSPAY_PREFIJO_WEB',
                        'label' => $this->l('Prefijo Web')
                    ),
                    array(
                        'type' => 'text',
                        'desc' => $this->l('Descripción en página externa de Pagos'),
                        'name' => 'ADAMSPAY_LABEL_DEUDAS',
                        'label' => $this->l('Label Deudas')
                    ),
                    array(
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-key"></i>',
                        'desc' => $this->l('AdamsPay.com / Configuración / Aplicaciones / Api Key'),
                        'name' => 'ADAMSPAY_API_KEY_APP',
                        'label' => $this->l('AdamsPay Api Key')
                    ),

                    array(
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-key"></i>',
                        'desc' => $this->l('AdamsPay.com / Configuración / Aplicaciones / Api Secret'),
                        'name' => 'ADAMSPAY_API_SECRET_APP',
                        'label' => $this->l('AdamsPay Api Secret')
                    ),
                    array(
                        'type' => 'text',
                        'desc' => $this->l('El valor de este campo lo debe de asignar tambien dentro AdamsPay.com / Configuración / Aplicaciones / Url de retorno'),
                        'name' => 'ADAMSPAY_URL_RESPUESTA',
                        'label' => $this->l('AdamsPay Url Retorno'),
                        'disabled' => true
                    ),
                    array(
                        'type' => 'text',
                        'desc' => $this->l('El valor de este campo lo debe de asignar tambien dentro AdamsPay.com / Configuración / Aplicaciones / Webhook de la APP'),
                        'name' => 'ADAMSPAY_URL_WEBHOOK',
                        'label' => $this->l('AdamsPay Url Webhook'),
                        'disabled' => true
                    ),
                    array(
                        'type' => 'text',
                        'desc' => $this->l('Mensaje mostrado al usuario en caso de que el pedido aún se encuentre pendiente de pago'),
                        'name' => 'ADAMSPAY_MENSAJE_PAGO_PENDIENTE',
                        'label' => $this->l('Mensaje por Pago Pendiente'),
                    ),

                    array(
                        'type' => 'text',
                        'desc' => $this->l('Valor de la etiqueta para el método de pago de AdamsPay'),
                        'name' => 'ADAMSPAY_LABEL_METODO_PAGO',
                        'label' => $this->l('Etiqueta del método de pago'),
                    )

                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'ADAMSPAY_PREFIJO_WEB' => Configuration::get('ADAMSPAY_PREFIJO_WEB', null),
            'ADAMSPAY_LABEL_DEUDAS' => Configuration::get('ADAMSPAY_LABEL_DEUDAS', null),
            'ADAMSPAY_API_KEY_APP' => Configuration::get('ADAMSPAY_API_KEY_APP', null),
            'ADAMSPAY_API_SECRET_APP' => Configuration::get('ADAMSPAY_API_SECRET_APP', null),
            'ADAMSPAY_MODO_PRODUCCION' => Configuration::get('ADAMSPAY_MODO_PRODUCCION', null),
            'ADAMSPAY_URL_RESPUESTA' => Configuration::get('ADAMSPAY_URL_RESPUESTA', $this->url_respuesta),
            'ADAMSPAY_URL_WEBHOOK' => Configuration::get('ADAMSPAY_URL_WEBHOOK', $this->url_webhook),
            'ADAMSPAY_URL_REDIRECT' => Configuration::get('ADAMSPAY_URL_REDIRECT', $this->url_redirect_adamspay),
            'ADAMSPAY_MENSAJE_PAGO_PENDIENTE' => Configuration::get('ADAMSPAY_MENSAJE_PAGO_PENDIENTE', null),
            'ADAMSPAY_LABEL_METODO_PAGO' => Configuration::get('ADAMSPAY_LABEL_METODO_PAGO', null),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();
        foreach (array_keys($form_values) as $key) {
            if (!in_array($key, $this->callback_urls)) {
                Configuration::updateValue($key, Tools::getValue($key));
            }
        }
        /**
         * Retorna verdadero si la configuración es correcta, y retorna un array de mensajes en caso de error
         * @var mixed
         */
        return $validar = AdamspayHelper::validarConfiguracionApp($this->getConfigFormValues());
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookBackOfficeHeader()
    {
        if (Tools::getValue('module_name') == $this->name) {
            $this->context->controller->addJS($this->_path.'views/js/back.js');
            $this->context->controller->addCSS($this->_path.'views/css/back.css');
        }
    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
        $this->context->controller->addJS($this->_path.'views/js/front.js');
        $this->context->controller->addCSS($this->_path.'views/css/front.css');
    }

    /**
     * This method is used to render the payment button,
     * Take care if the button should be displayed or not.
     */
    public function hookPayment($params)
    {
        $currency_id = $params['cart']->id_currency;
        $currency = new Currency((int)$currency_id);

        if (in_array($currency->iso_code, $this->limited_currencies) == false)
            return false;

        $this->smarty->assign('module_dir', $this->_path);

        return $this->display(__FILE__, 'views/templates/hook/payment.tpl');
    }

    /**
     * This hook is used to display the order confirmation page.
     */
    public function hookPaymentReturn($params)
    {
        $this->smarty->assign('mensaje', Tools::getValue('mensaje'));
        if ($this->active == false)
            return;

        $order = $params['objOrder'];

        if ($order->getCurrentOrderState()->id != Configuration::get('PS_OS_ERROR'))
            $this->smarty->assign('status', 'ok');

        $this->smarty->assign(array(
            'id_order' => $order->id,
            'reference' => $order->reference,
            'params' => $params,
            'total' => Tools::displayPrice($params['total_to_pay'], $params['currencyObj'], false),
        ));

        return $this->display(__FILE__, 'views/templates/hook/confirmation.tpl');
    }

    /**
     * Return payment options available for PS 1.7+
     *
     * @param array Hook parameters
     *
     * @return array|null
     */
    public function hookPaymentOptions($params)
    {
        if (!$this->active) {
            return;
        }
        if (!$this->checkCurrency($params['cart'])) {
            return;
        }
        
        $descripcion_adamspay = 'Por favor, confirme los términos del servicio y Confirme su pedido,  
            se le redireccionará a la Web Segura de AdamsPay.com donde 
            seleccionará su método de pago preferido para finalizar la compra.';
        
        $label_metodo_pago = Configuration::get('ADAMSPAY_LABEL_METODO_PAGO', null);

        $option = new \PrestaShop\PrestaShop\Core\Payment\PaymentOption();
        $option->setCallToActionText($label_metodo_pago)
            ->setAdditionalInformation($this->l($descripcion_adamspay))
            ->setlogo($this->l($this->_path . '/views/img/adams-logo-150px.png'))
            ->setAction($this->context->link->getModuleLink($this->name, 'redirect', array(), true));

        return [
            $option
        ];
    }

    /**
     * @param mixed $cart
     * 
     * @return boolean
     */
    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);
        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }

    public function hookActionPaymentConfirmation()
    {
        /* Place your code here. */
    }

    public function hookDisplayPayment()
    {
        /* Place your code here. */
    }

    public function hookDisplayOrderConfirmation($params)
    {

        $this->smarty->assign('mensaje', Tools::getValue('mensaje'));
        if ($this->active == false)
            return;

        $order = $params['order'];

        $deuda_local = AdamspayDeuda::obtenerDeudaPorIdOrden($order->id);

        $mensaje = Configuration::get('ADAMSPAY_MENSAJE_PAGO_PENDIENTE', '');

        if ($order->getCurrentOrderState()->id != Configuration::get('PS_OS_ERROR'))
        $this->smarty->assign('status', 'ok');

        $this->smarty->assign(array(
            'total_to_pay' => Tools::displayPrice(
                $params['order']->getOrdersTotalPaid(),
                new Currency($params['order']->id_currency),
                false
            ),
            'shop_name' => $this->context->shop->name,
            'status' => 'ok',
            'id_order' => $params['order']->id,
            'url_pago' => Configuration::get('ADAMSPAY_URL_REDIRECT').'&id_order='. $params['order']->id,
            'deuda_status' => $deuda_local['estado_deuda'],
            'order_status' => $order->current_state,
            'mensaje' => $mensaje
        ));

        if (isset($params['order']->reference) && !empty($params['order']->reference)) {
            $this->smarty->assign('reference', $params['order']->reference);
        }

        return $this->display(__FILE__, 'views/templates/hook/order_confirmation.tpl');
    }

    public function hookDisplayPaymentReturn($params)
    {
        $this->smarty->assign('mensaje', Tools::getValue('mensaje'));
        if ($this->active == false)
            return;
        
        $order = $params['order'];

        $deuda_local = AdamspayDeuda::obtenerDeudaPorIdOrden($order->id);

        if ($order->getCurrentOrderState()->id != Configuration::get('PS_OS_ERROR'))
            $this->smarty->assign('status', 'ok');

        $this->smarty->assign(array(
            'total_to_pay' => Tools::displayPrice(
                $params['order']->getOrdersTotalPaid(),
                new Currency($params['order']->id_currency),
                false
            ),
            'shop_name' => $this->context->shop->name,
            'status' => 'ok',
            'id_order' => $params['order']->id,
            'url_pago' => Configuration::get('ADAMSPAY_URL_REDIRECT').'&id_order='. $params['order']->id,
            'deuda_status' => $deuda_local['estado_deuda'],
            'order_status' => $order->current_state
        ));

        if (isset($params['order']->reference) && !empty($params['order']->reference)) {
            $this->smarty->assign('reference', $params['order']->reference);
        }

        return $this->display(__FILE__, 'views/templates/hook/confirmation.tpl');
    }

    public function hookDisplayPaymentTop()
    {
        /* Place your code here. */
    }

    /**
     * @hook displayOrderDetail
     */
    public function hookDisplayOrderDetail($params)
    {
        $this->smarty->assign('mensaje', Tools::getValue('mensaje'));
        if ($this->active == false)
            return;

        $order = $params['order'];

        $deuda_local = AdamspayDeuda::obtenerDeudaPorIdOrden($order->id);

        if ($order->getCurrentOrderState()->id != Configuration::get('PS_OS_ERROR'))
        $this->smarty->assign('status', 'ok');

        $this->smarty->assign(array(
            'total_to_pay' => Tools::displayPrice(
                $params['order']->getOrdersTotalPaid(),
                new Currency($params['order']->id_currency),
                false
            ),
            'shop_name' => $this->context->shop->name,
            'status' => 'ok',
            'id_order' => $params['order']->id,
            'url_pago' => Configuration::get('ADAMSPAY_URL_REDIRECT').'&id_order='. $params['order']->id,
            'deuda_status' => $deuda_local['estado_deuda'],
            'order_status' => $order->current_state,
            'mensaje' => Configuration::get('ADAMSPAY_MENSAJE_PAGO_PENDIENTE')
        ));

        if (isset($params['order']->reference) && !empty($params['order']->reference)) {
            $this->smarty->assign('reference', $params['order']->reference);
        }

        return $this->display(__FILE__, 'views/templates/hook/order_detail.tpl');
    }

    /**
     * @hook displayAdminOrderLeft
     */
    public function hookDisplayAdminOrderLeft()
    {
        $id_order = Tools::getValue('id_order');

        $deuda = AdamspayDeuda::obtenerDeudaPorIdOrden($id_order);

        $this->context->smarty->assign(array(
            'deuda' => $deuda
        ));

        return $this->display(__FILE__, 'views/templates/admin/admin_ordenes.tpl');
    }

    public function hookActionOrderStatusPostUpdate($params){
        if($params['newOrderStatus']->id == Configuration::get('PS_OS_CANCELED')){
            $deuda_local = AdamspayDeuda::obtenerDeudaPorIdOrden($params['id_order']);

            if($deuda_local){
                //post data para actualizar el estado de la deuda a cancelada
                $parametros = [
                    'debt' => [
                        'payStatus' => [
                            'status' => 'canceled'
                        ]
                    ]
                ];

                $adamspay = new AdamspayApi();
                $response = $adamspay->cancelarDeuda($deuda_local['id_deuda']);
                // $response = $adamspay->actualizarDeuda($deuda_local['id_deuda'], $parametros);

                if(isset($response['meta']) && $response['meta']['status'] == 'success'){
                    $deuda_local = new AdamspayDeuda($deuda_local['row_id']);
                    $deuda_local->estado_orden = Configuration::get('PS_OS_CANCELED');
                    $deuda_local->estado_deuda = AdamspayDeuda::DEUDA_CANCELADA;
                    if(!$deuda_local->save()){
                        AdamspayLog::error('No se pudo actualizar el estado de la deuda local '.$deuda_local->id_deuda, __FUNCTION__);
                    }
                }
            }

        }
    }

    /**
     * crea el estado para la orden que aun no fue pagada
     */
    public function setStatus(){
        $status = array();
        $status['send_email'] = false;
        $status['invoice'] = false;
        $status['unremovable'] = true;
        $status['paid'] = false;
        $status['template'] = '';
        if (!Configuration::get('ADAMSPAY_PAGO_PENDIENTE')) {
            $add_state = $this->addState($this->l('Pendiente de pago'), '#0404B4', $status);
            Configuration::updateValue('ADAMSPAY_PAGO_PENDIENTE', $add_state);
        }
    }

    /**
     * Inserta un nuevo estado dentro de los estados posibles de una orden
     * @param mixed $en
     * @param mixed $color
     * @param mixed $status
     * 
     * @return int
     */
    private function addState($en, $color, $status)
    {
        $order_state = new OrderState();
        $order_state->name = array();
        foreach (Language::getLanguages() as $language) {
            $order_state->name[$language['id_lang']] = $en;
        }
        $order_state->name[$this->context->language->id] = $en;
        $order_state->send_email = $status['send_email'];
        $order_state->color = $color;
        $order_state->hidden = false;
        $order_state->unremovable = $status['unremovable'];
        $order_state->delivery = false;
        $order_state->logable = false;
        $order_state->invoice = $status['invoice'];
        $order_state->paid = $status['paid'];
        $order_state->template = $status['template'];
        if ($order_state->add()) {
            if (file_exists(dirname(__FILE__) . '/logo.gif')) {
                $dir_name = dirname(__FILE__) . '/../../img/os/';
                Tools::copy(dirname(__FILE__) . '/logo.gif', $dir_name . (int) $order_state->id . '.gif');
            }
        }
        return $order_state->id;
    }
}
