<?php
namespace Adamspay;

require_once(_PS_ROOT_DIR_ . '/config/config.inc.php');
require_once(_PS_ROOT_DIR_ . '/init.php');
require_once(_PS_ROOT_DIR_ . '/modules/adamspay/adamspay.php');

use Configuration;
use Tools;
use FileLogger;
use DateTimeImmutable;
use DateInterval;
use DateTimeZone;
use DateTime;
use Adamspay\AdamspayHelper;

class AdamspayApi {
    /**
     * @param mixed $id_deuda
     * @return array
     */
    public function cancelarDeuda($id_deuda){
        $url = $this->obtenerApiUrl().'/debts/'.$id_deuda;
        $apiKey = Configuration::get('ADAMSPAY_API_KEY_APP');
        $header = ['apikey: ' . $apiKey, 'Content-Type: application/json'];
        $params = false;
        $method = 'DELETE';

        return $this->ejecutarPeticion($method, $url, $params, $header, __FUNCTION__);
    }

    /**
     * @param mixed $id_deuda
     * @return array
     */
    public function actualizarDeuda($id_deuda, $params)
    {
        $url = $this->obtenerApiUrl() . '/debts/' . $id_deuda;
        $apiKey = Configuration::get('ADAMSPAY_API_KEY_APP');
        $header = ['apikey: ' . $apiKey, 'Content-Type: application/json'];
        $method = 'PUT';

        return $this->ejecutarPeticion($method, $url, $params, $header, __FUNCTION__);
    }

    /**
     * Retorna la informacion de la configuracion de la aplicacion en Adamspay
     * @return array
     */
    public function obtenerInformacionApp(){
        $url = $this->obtenerApiUrl() . '/apps/self';
        $apiKey = Configuration::get('ADAMSPAY_API_KEY_APP');
        $header = ['apikey: ' . $apiKey, 'Content-Type: application/json'];
        $params = false;
        $method = 'GET';

        // NONCE es una cadena única aleatoria cualquiera
        $secretNonce = \md5(\uniqid() . time());
        $secretHash = AdamspayHelper::base64url_encode( \hash_hmac('sha256', $secretNonce , Configuration::get('ADAMSPAY_API_SECRET_APP'), true)  );
        $url .= '?secret_nonce='.$secretNonce.'&secret_hash='.$secretHash;

        return $this->ejecutarPeticion($method, $url, $params, $header, __FUNCTION__);
    }

    /**
     * @param mixed $id_deuda
     * 
     * @return array
     */
    public function obtenerDetalleDeuda($id_deuda)
    {
        $url = $this->obtenerApiUrl() . '/debts/' . $id_deuda;
        $apiKey = Configuration::get('ADAMSPAY_API_KEY_APP');
        $header = ['apikey: ' . $apiKey, 'Content-Type: application/json'];
        $params = false;
        $method = 'GET';

        return $this->ejecutarPeticion($method, $url, $params, $header, __FUNCTION__);
    }

    /**
     * @param mixed $total
     * @param int $id_orden
     * @param string $moneda
     * 
     * @return array
     */
    public function crearDeuda($total, $id_orden, $moneda){
        $url = $this->obtenerApiUrl() . '/debts?update_if_exists=1';
        $apiKey = Configuration::get('ADAMSPAY_API_KEY_APP');
        $header = ['apikey: ' . $apiKey, 'Content-Type: application/json'];
        $method = 'POST';
        $prefijo_tienda = Configuration::get('ADAMSPAY_PREFIJO_WEB');

        /*
         * El ID Deuda se compone por ADAMSPAY_PREFIJO_WEB + el ID de Orden confirmada de prestashop.
         * En cada orden se guarda el ID  de deuda, entonces, si cambia el parametro ADAMSPAY_PREFIJO_WEB
         * cambiaría el formato ID Deuda pero nosotros buscaríamos de lo que se guardó en cada orden.
         * */
        $identificador = $prefijo_tienda . $id_orden;

        // Hora DEBE ser en UTC!
        $ahora = new DateTimeImmutable('now', new DateTimeZone('UTC'));
        $expira = $ahora->add(new DateInterval('P2D'));

        // Crear simple deuda (Caratula o Label configurable)
        $deuda = [
            'docId' => $identificador,
            'label' => Configuration::get('ADAMSPAY_LABEL_DEUDAS'),
            'amount' => [
                'currency' => $moneda,
                'value' => AdamspayHelper::formatearMoneda($total, $moneda)
            ],
            'validPeriod' => [
                'start' => $ahora->format(DateTime::ATOM),
                'end' => $expira->format(DateTime::ATOM)
            ]
        ];

        // Crear JSON para el post
        $parametros = json_encode(['debt' => $deuda]);

        return $this->ejecutarPeticion($method, $url, $parametros, $header, __FUNCTION__);
    }

    /**
     * @return string url
     */
    public function obtenerApiUrl()
    {
        $apiUrl = null;

        switch (Configuration::get('ADAMSPAY_MODO_PRODUCCION')) {
            case 1:
                $apiUrl = Configuration::get('ADAMSPAY_URL_PRODUCCION');
                break;

            case 0:
                $apiUrl = Configuration::get('ADAMSPAY_URL_PRUEBAS');
                break;

            case 2:
                $apiUrl = Configuration::get('ADAMSPAY_URL_DESARROLLO');
                break;

            default:
                break;
        }

        return $apiUrl;
    }

    /**
     * Para realizar peticiones http
     * @param string $method
     * @param string $url
     * @param mixed $params
     * @param mixed $headers
     * @param string $function
     * 
     */
    private function ejecutarPeticion($method, $url, $params = false, $headers = false, $function = '')
    {
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_ENCODING, '');
        curl_setopt($ch, CURLOPT_TIMEOUT, 30);
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

        if ($params) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
        }

        $json = curl_exec($ch);
        $error = curl_error($ch);
        $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if (!$error && ($data = Tools::jsonDecode($json, true))) {
            if (!$this->verificarErrores($data, $http_code, $function)) {
                return $data;
            }
        }

        return false;
    }

    /**
     * Verifica si hay errores, y los agrega en un archivo log
     * @param mixed $data
     * @param mixed $http_code
     * @param mixed $function
     * 
     * @return boolean
     */
    private function verificarErrores($data, $http_code, $function)
    {
        if ((int)$http_code <> 200 && $data['meta']['status'] <> 'success') {
            $error = '(HTTP ' . $http_code . ') ' . $data['meta']['code'] . ': ' . $data['meta']['description'];
            AdamspayLog::error($error, $function);
        }

        return false;
    }
}